Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(400)

Unified Diff: components/safe_browsing/csd.proto

Issue 2905343002: Show interstitial on a password on focus ping with PHISHING verdict. (Closed)
Patch Set: nit Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/safe_browsing/csd.proto
diff --git a/components/safe_browsing/csd.proto b/components/safe_browsing/csd.proto
index 7bb5920bd7caebe6c083550bfb8806447f7b7e24..8d8b4158c78d31391c3f338eb1f3093e15e529a5 100644
--- a/components/safe_browsing/csd.proto
+++ b/components/safe_browsing/csd.proto
@@ -262,6 +262,10 @@ message LoginReputationClientResponse {
// Deprecated.
optional bool DEPRECATED_cache_expression_exact_match = 4 [deprecated = true];
+
+ // A token unique to each request which correlates response and post-warning
+ // actions.
+ optional bytes verdict_token = 5;
}
message ClientMalwareResponse {
@@ -904,6 +908,7 @@ message ClientSafeBrowsingReportRequest {
DANGEROUS_DOWNLOAD_RECOVERY = 6;
DANGEROUS_DOWNLOAD_WARNING = 7;
DANGEROUS_DOWNLOAD_BY_API = 10;
+ PASSWORD_PROTECTION_PHISHING_URL = 12;
}
message HTTPHeader {
@@ -984,9 +989,10 @@ message ClientSafeBrowsingReportRequest {
// Whether user visited this origin before.
optional bool repeat_visit = 9;
// The same token in ClientDownloadResponse. This field is only set if its
// report type is DANGEROUS_DOWNLOAD_RECOVERY, DANGEROUS_DOWNLOAD_WARNING or
// DANGEROUS_DOWNLOAD_BY_API.
optional bytes token = 15;
}
@@ -984,9 +989,10 @@ message ClientSafeBrowsingReportRequest {
// Whether user visited this origin before.
optional bool repeat_visit = 9;
- // The same token in ClientDownloadResponse. This field is only set if its
- // report type is DANGEROUS_DOWNLOAD_RECOVERY, DANGEROUS_DOWNLOAD_WARNING or
- // DANGEROUS_DOWNLOAD_BY_API.
+ // The same token in ClientDownloadResponse or LoginReputationClientResponse.
+ // This field is only set if its report type is DANGEROUS_DOWNLOAD_RECOVERY,
+ // DANGEROUS_DOWNLOAD_WARNING, DANGEROUS_DOWNLOAD_BY_API or
+ // PASSWORD_PROTECTION_PHISHING_URL.
optional bytes token = 15;
}

Powered by Google App Engine
This is Rietveld 408576698